<?php
/**
* FiloBlu srl
*
* @category   FiloBlu
* @package    FiloBlu_Eva
* @copyright  FiloBlu srl (http://www.filoblu.com)
*
*/

namespace FiloBlu\Eva\Helper;

class Data extends \Magento\Framework\Url\Helper\Data
{

    protected $_productCollectionFactory;
    protected $_categoryFactory;
    protected $_scopeConfig;
    protected $_helperDesign;
    protected $_storeManager;
    protected $_helperCategoryPagination;
    protected $_bannerCollection;
    protected $_registry;

    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Catalog\Model\ResourceModel\Product\CollectionFactory $productCollectionFactory,
        \Magento\Catalog\Model\CategoryFactory $categoryFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \FiloBlu\CategoryPagination\Helper\Data $helperCategoryPagination,
        \Blackbird\ContentManager\Model\ResourceModel\Content\CollectionFactory $bannerCollection,
        \Magento\Framework\Registry $registry,
        \FiloBlu\Design\Helper\Data $helperDesign
    ) {
        $this->_categoryFactory = $categoryFactory;
        $this->_productCollectionFactory = $productCollectionFactory;
        $this->_scopeConfig = $context->getScopeConfig();
        $this->_helperCategoryPagination = $helperCategoryPagination;
        $this->_bannerCollection = $bannerCollection;
        $this->_registry = $registry;
        $this->_helperDesign = $helperDesign;
        $this->_storeManager = $storeManager;
    }

    public function getProductCollection($categoryId)
    {
        $category = $this->_categoryFactory->create()->load($categoryId);
        $collection = $this->_productCollectionFactory->create();
        $collection->addAttributeToSelect('*');
        $collection->addCategoryFilter($category);
        $collection->addAttributeToFilter('visibility', \Magento\Catalog\Model\Product\Visibility::VISIBILITY_BOTH);
        $collection->addAttributeToFilter('status',\Magento\Catalog\Model\Product\Attribute\Source\Status::STATUS_ENABLED);
        $collection->setPageSize(20);
        return $collection;
    }

    public function getProductPlaceholder() {

        $configPlaceholder = $this->_scopeConfig->getValue(
            "catalog/placeholder/image_placeholder",
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );

        $placeholder = $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA) . 'catalog/product/placeholder/' . $configPlaceholder;

        return $placeholder;
    }

    public function getMediaPath() {

        $path = $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA);

        return $path;
    }

    public function getConfig($config_path)
    {
        return $this->_scopeConfig->getValue(
            $config_path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE
        );
    }

    public function getCategoryBannerCollection(){

        $currentCat = $this->_registry->registry('current_category');
        $helperCategoryPagination = $this->_helperCategoryPagination;

        if ($currentCat) {
            $currentCatId = $currentCat->getId();
        }

        // Get the Banner Category associated to the current category
        if ($currentCat && (!$helperCategoryPagination->getConfig('general/default_config_onfilter') || ($helperCategoryPagination->getConfig('general/default_config_onfilter') && !$helperCategoryPagination->isFilterApplied()))) {
            $bannerCollection = $this->_bannerCollection->create()
                ->addContentTypeFilter('category_banner')
                ->addAttributeToFilter('status', 1);

            if ($bannerCollection->getSize() > 0) {
                $bannerCollection->addAttributeToFilter('cb_category', $currentCatId)->addAttributeToSelect('*');
            }

            return $bannerCollection;
        }
    }

    public function getPercentageDiscount($basePrice, $specialPrice) {
        try {
            $diff = ($basePrice - $specialPrice);
            if ($basePrice > 0) {
                $percentVal = round((($diff * 100) / $basePrice), 0);
            } else {
                $percentVal = 0;
            }

            return $percentVal;
        } catch (Exception $ex) {
            return 0;
        }
    }

}
